@@ -54,12 +54,12 @@ is_close:{is_close}
 
     def __connect(self):
         """
-        连接日志服务器. 若首次连接失败, 则重试 3 次, 每次间隔 60 秒钟.
+        连接服务端. 若首次连接失败, 则重试 3 次, 每次间隔 60 秒钟.
         """
         try:
             self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self.sock.connect(self.server_address)
-            print('连接日志服务器成功')
+            print('连接服务端成功')
         except:
             i = 0
             while i < 3:
@@ -76,11 +76,11 @@ is_close:{is_close}
                 break
 
             if i >= 3:
-                print('重连日志服务器失败')
+                print('重连服务端失败')
                 # 直接结束客户端进程
                 sys.exit()
             else:
-                print('重连日志服务器成功')
+                print('重连服务端成功')
 
     def __send(self, message=None, is_close=0, filename=None, lineno=None):
         """
@@ -91,6 +91,7 @@ is_close:{is_close}
         :param lineno: 源码行号
         :return:
         """
+        # 发送
         try:
             hostname, IP = util.get_hostname_IP()
             datetime = util.get_datetime()
@@ -100,11 +101,11 @@ is_close:{is_close}
 
             self.sock.sendall(message_log.encode('utf8'))
         except Exception:
-            # 这里发送失败可能是因为服务器进程崩溃, 网络问题,
+            # 这里发送失败可能是因为服务端进程崩溃, 网络问题,
             # 可以尝试不做处理, 避免因为日志客户端的异常影响到使用它的应用程序.
             # TODO: 添加发送失败报警
             pass
-            # raise
+            raise
 
     def send(self, message=None):
         """
@@ -121,7 +122,7 @@ is_close:{is_close}
 
     def close(self):
         """
-        关闭连接与日志服务器之间的连接
+        关闭连接与服务端之间的连接
         :return:
         """
         self.__send(is_close=1)
